@@ -2,6 +2,8 @@ import typing as t
 from datetime import datetime
 
 import rsa
+from flask import has_app_context, current_app
+from sqlalchemy.orm.exc import NoResultFound
 
 from dimensigon import defaults
 from dimensigon.domain.entities.base import EntityReprMixin, UUIDEntityMixin
@@ -9,8 +11,10 @@ from dimensigon.utils.helpers import get_now
 from dimensigon.utils.typos import PrivateKey, PublicKey, UtcDateTime
 from dimensigon.web import db
 
+current = {}
 
-class Dimension(db.Model, UUIDEntityMixin, EntityReprMixin):
+
+class Dimension(UUIDEntityMixin, EntityReprMixin, db.Model):
     __tablename__ = 'L_dimension'
     name = db.Column(db.String(40), nullable=False, unique=True)
     private = db.Column(PrivateKey, unique=True)
@@ -21,7 +25,7 @@ class Dimension(db.Model, UUIDEntityMixin, EntityReprMixin):
     def __init__(self, name: str, private: t.Union[rsa.PrivateKey, bytes] = None,
                  public: t.Union[rsa.PublicKey, bytes] = None, created_at: datetime = get_now(), current=False,
                  **kwargs):
-        UUIDEntityMixin.__init__(self, **kwargs)
+        super().__init__(**kwargs)
         self.name = name
         if isinstance(private, bytes):
             self.private = rsa.PrivateKey.load_pkcs1(private)
@@ -36,7 +40,18 @@ class Dimension(db.Model, UUIDEntityMixin, EntityReprMixin):
 
     @classmethod
     def get_current(cls) -> 'Dimension':
-        return cls.query.filter_by(current=True).one_or_none()
+        global current
+        if has_app_context():
+            app = current_app._get_current_object()
+            if app not in current:
+                entity = cls.query.filter_by(current=True).one()
+                if entity:
+                    db.session.expunge(entity)
+                    current[app] = entity
+                else:
+                    raise NoResultFound('No row was found for one()')
+            return db.session.merge(current[app], load=False)
+        return cls.query.filter_by(current=True).one()
 
     def to_json(self):
         return {'id': str(self.id) if self.id else None, 'name': self.name,
