@@ -1,9 +1,9 @@
 import argparse
 import inspect
-import os
 import shlex
 
 from prompt_toolkit import PromptSession
+from prompt_toolkit.clipboard.pyperclip import PyperclipClipboard
 from prompt_toolkit.history import InMemoryHistory
 from prompt_toolkit.styles import Style
 
@@ -50,21 +50,22 @@ def call_func_with_signature(cmd_params):
     except Exception as e:
         dprint(e)
 
+
 style = Style.from_dict({
     # User input (default text).
     # '':          '#ff0066',
 
     # Prompt.
     'username': 'green',
-    'at':       '#884444',
-    'host':     'green bold',
-    'path':     'ansicyan',
+    'at': '#884444',
+    'host': 'green bold',
+    'path': 'ansicyan',
 })
 
 
 def interactive():
     session = PromptSession(completer=DshellCompleter.from_nested_dict(nested_dict),
-                            history=get_history('main', InMemoryHistory()),
+                            history=get_history('main', InMemoryHistory()), clipboard=PyperclipClipboard(),
                             enable_history_search=True, enable_suspend=True)
 
     parser = ArgumentParserRaise(allow_abbrev=False, prog='')
