@@ -7,8 +7,6 @@ from prompt_toolkit import prompt
 from prompt_toolkit.auto_suggest import AutoSuggestFromHistory
 from prompt_toolkit.completion import merge_completers
 from prompt_toolkit.history import InMemoryHistory
-from prompt_toolkit.lexers import PygmentsLexer
-from pygments.lexers.python import PythonLexer
 
 import dimensigon.dshell.network as ntwrk
 from dimensigon.domain.entities import ActionType
@@ -29,17 +27,11 @@ form = {
     "action_type": dict(validator=v.Choice([at.name for at in ActionType if at.name != 'NATIVE']),
                         history=InMemoryHistory()),
     "code": dict(edit=code_extension, history=InMemoryHistory(), converter=c.MultiLine),
-    "expected_stdout": dict(multiline=True, mouse_support=True, history=InMemoryHistory(),
-                            converter=c.MultiLine),
-    "expected_stderr": dict(multiline=True, mouse_support=True, history=InMemoryHistory(),
-                            converter=c.MultiLine),
+    "expected_stdout": dict(multiline=True, mouse_support=True, history=InMemoryHistory(), converter=c.MultiLine),
+    "expected_stderr": dict(multiline=True, mouse_support=True, history=InMemoryHistory(), converter=c.MultiLine),
     "expected_rc": dict(validator=v.Int(), converter=c.Int, history=InMemoryHistory()),
-    "parameters": dict(multiline=True, mouse_support=True, lexer=PygmentsLexer(PythonLexer), validator=v.JSON(),
-                       converter=c.JSON, history=InMemoryHistory()),
-    "schema": dict(edit='.yaml', mouse_support=True, validator=v.JSON, history=InMemoryHistory(), converter=c.Yaml),
-    "system_kwargs": dict(multiline=True, mouse_support=True, lexer=PygmentsLexer(PythonLexer),
-                          validator=v.JSON(), converter=c.JSON,
-                          history=InMemoryHistory()),
+    "schema": dict(edit='.yaml', validator=v.JSON, history=InMemoryHistory(), converter=c.Yaml),
+    "system_kwargs": dict(edit='.yaml', validator=v.JSON, history=InMemoryHistory(), converter=c.Yaml),
     "pre_process": dict(edit='.py', history=InMemoryHistory(), converter=c.MultiLine),
     "post_process": dict(edit='.py', history=InMemoryHistory(), converter=c.MultiLine),
     "target": dict(completer=merge_completers([granule_completer, server_name_completer]), history=InMemoryHistory()),
@@ -99,7 +91,8 @@ def subprompt(entity, changed=False, ask_all=False, parent_prompt=None):
         if namespace.cmd == 'preview':
             if namespace.subcmd == 'action':
                 if entity.get('action_template_id', None):
-                    resp = ntwrk.get('api_1_0.actiontemplateresource', view_data={'action_template_id': entity['action_template_id']})
+                    resp = ntwrk.get('api_1_0.actiontemplateresource',
+                                     view_data={'action_template_id': entity['action_template_id']})
                     dprint(resp)
                 else:
                     dprint('no action_template_id set')
