@@ -1,7 +1,6 @@
 from flask import Blueprint
 from flask_restful import Api
 
-
 api_bp = Blueprint('api_1_0', __name__, url_prefix='/api/v1.0')
 api = Api(api_bp)
 
@@ -52,4 +51,7 @@ api.add_resource(TransferList, '/transfers')
 api.add_resource(TransferResource, '/transfers/<transfer_id>')
 
 api.add_resource(UserList, '/users')
-api.add_resource(UserResource, '/users/<user_id>')
\ No newline at end of file
+api.add_resource(UserResource, '/users/<user_id>')
+
+api.add_resource(VaultList, '/vault')
+api.add_resource(VaultResource, '/vault/<scope>/<name>', '/vault/<name>')
